@@ -1,8 +1,10 @@
 """ GwSchema Enums used in gridworks """
 from gridworks.enums.algo_cert_type import AlgoCertType
+from gridworks.enums.core_g_node_role import CoreGNodeRole
 from gridworks.enums.g_node_role import GNodeRole
 from gridworks.enums.g_node_status import GNodeStatus
 from gridworks.enums.gni_status import GniStatus
+from gridworks.enums.market_type_name import MarketTypeName
 from gridworks.enums.message_category import MessageCategory
 from gridworks.enums.message_category_symbol import MessageCategorySymbol
 from gridworks.enums.strategy_name import StrategyName
@@ -12,9 +14,11 @@ from gridworks.enums.universe_type import UniverseType
 
 __all__ = [
     "AlgoCertType",
+    "CoreGNodeRole",
     "GNodeRole",
     "GNodeStatus",
     "GniStatus",
+    "MarketTypeName",
     "MessageCategory",
     "MessageCategorySymbol",
     "StrategyName",
